<?php

/**
 * @file
 * Contains \Drupal\ek_jitsi\Form\Settings.
 */

namespace Drupal\ek_jitsi\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure ek_jitsi settings for this site.
 */
class Settings extends ConfigFormBase {

    /** @var string Config settings */
    const SETTINGS = 'ek_jitsi.settings';

    /**
     * {@inheritdoc}
     */
    public function getFormId() {
        return 'ek_jitsi_settings';
    }

    /**
     * {@inheritdoc}
     */
    protected function getEditableConfigNames() {
        return [
            static::SETTINGS,
        ];
    }

    /**
     * {@inheritdoc}
     */
    public function buildForm(array $form, FormStateInterface $form_state) {
        $config = $this->config(static::SETTINGS);

        if(!\Drupal::config('ek_jitsi_domain')->get('ek_jitsi_domain')){
            $default = 'meet.jit.si';
        } else {
            $default = \Drupal::config('ek_jitsi_domain')->get('ek_jitsi_domain');
        }
        $form['ek_jitsi_domain'] = [
            '#type' => 'textfield',
            '#required' => TRUE,
            '#title' => $this->t('Signal server'),
            '#attributes' => array('placeholder' => t('domain')),
            '#default_value' => $default,
            '#description' => $this->t('Server that manage video connections')
        ];

        
        return parent::buildForm($form, $form_state);
    }

    /**
     * {@inheritdoc}
     */
    public function validateForm(array &$form, FormStateInterface $form_state) {
        
    }

    /**
     * {@inheritdoc}
     */
    public function submitForm(array &$form, FormStateInterface $form_state) {
        
        // Retrieve the configuration
        $this->configFactory->getEditable(static::SETTINGS)
                // Set the submitted configuration setting
                ->set('ek_jitsi_domain', $form_state->getValue('ek_jitsi_domain'))
                ->save();

        parent::submitForm($form, $form_state);
    }

}
